.. scikit-downscale documentation master file, created by
   sphinx-quickstart on Wed Oct  9 13:59:33 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Scikit-downscale: toolkit for statistical downscaling
=====================================================

Scikit-downscale is a toolkit for statistical downscaling using Scikit-Learn_.
It is meant to support the development of new and existing downscaling
methods in a common framework. It implements Scikit-learn's `fit`/`predict` API
facilitating the development of a wide range of statitical downscaling models.
Utilities and a high-level API built on Xarray_ and Dask_ support both
point-wise and global downscaling applications.

.. _Xarray: http://xarray.pydata.org
.. _Scikit-Learn: https://scikit-learn.org
.. _Dask: https://dask.org

Under Active Development
~~~~~~~~~~~~~~~~~~~~~~~~
Scikit-downscale is under active development. We are looking for additional
contributors to help fill out the list of downscaling methods supported here.
We are also looking to find collaborators interested in using deep learning
to build global downscaling tools. Get in touch with us on our
`GitHub page <https://github.com/jhamman/scikit-downscale>`_.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   roadmap
   api

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
